@@ -14,7 +14,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.112';
+our $VERSION = '2017.114';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -401,6 +401,18 @@ sub powerOfTwo($)
    }
   undef
  }
+
+#-------------------------------------------------------------------------------
+# Find log two of the lowest power of two greater than or equal to a number
+#-------------------------------------------------------------------------------
+
+sub containingPowerOfTwo($)
+ {my ($n) = @_;                                                                 # Number to check
+  for(0..128)
+   {return $_  if $n <= 1<<$_;
+   }
+  undef
+ }
 #-------------------------------------------------------------------------------
 # Documentation
 #-------------------------------------------------------------------------------
@@ -492,7 +504,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @ISA          = qw(Exporter);
 @EXPORT       = qw(formatTable);
-@EXPORT_OK    = qw(checkKeys dateStamp dateTimeStamp
+@EXPORT_OK    = qw(checkKeys containingPowerOfTwo dateStamp dateTimeStamp
 extractDocumentation fileList fileSize formatTableBasic
 genLValueArrayMethods genLValueHashMethods genLValueScalarMethods genLValueScalarMethodsWithDefaultValues
 indentString
@@ -609,7 +621,7 @@ modified under the same terms as Perl itself.
 =cut
 
 __DATA__
-use Test::More tests => 30;
+use Test::More tests => 40;
 if (1)                                                                          # Unicode
  {use utf8;
   my $z = "𝝰𝝱𝝲";
@@ -747,3 +759,15 @@ if (1)
  }
 
  ok trim(" a b ") eq join ' ', qw(a b);                                         # Trim
+
+ok  powerOfTwo(1) == 0;                                                         # Power of two
+ok  powerOfTwo(2) == 1;
+ok !powerOfTwo(3);
+ok  powerOfTwo(4) == 2;
+
+ok  containingPowerOfTwo(1) == 0;                                               # Containing power of two
+ok  containingPowerOfTwo(2) == 1;
+ok  containingPowerOfTwo(3) == 2;
+ok  containingPowerOfTwo(4) == 2;
+ok  containingPowerOfTwo(5) == 3;
+ok  containingPowerOfTwo(7) == 3;
